@@ -2,7 +2,6 @@
 
 [1] http://pypi.python.org/pypi/py-sendfile/
 """
-from sys import exc_info
 from errno import EAGAIN
 from sendfile import sendfile as original_sendfile
 from gevent.socket import wait_write
@@ -13,11 +12,10 @@ def gevent_sendfile(out_fd, in_fd, offset, count):
     while total_sent < count:
         try:
             _offset, sent = original_sendfile(out_fd, in_fd, offset + total_sent, count - total_sent)
-            #print '%s: sent %s [%d%%]' % (out_fd, sent, 100*total_sent/count)
+            #print('%s: sent %s [%d%%]' % (out_fd, sent, 100*total_sent/count))
             total_sent += sent
-        except OSError:
-            ex = exc_info()[1]
-            if ex[0] == EAGAIN:
+        except OSError as ex:
+            if ex.args[0] == EAGAIN:
                 wait_write(out_fd)
             else:
                 raise
